/*
 * (C) Copyright Pattern Recognition Group Delft. All rights reserved.
 *
 * SPRLIB.H : All the include files needed for the sprlib
 *
 * Made by : W.F. Schmidt
 *
 * Revision: 21-11-1995 Dick de Ridder (#ifdef DR1)
 *           Added a monitoring routine for realloc (see MONALLOC.C).
 *
 *           03-10-1996 Dick de Ridder (#ifdef DRML)
 *           Worked on Matlab-interface.
 *
 *           24-03-1996 Dick de Ridder (#ifdef DR2)
 *           New option for sprinit: INIT_HALT to make the program loop
 *           after an error. Convenient when debugging. 
 *
 * SccsId  : %Z%$RCSfile: sprlib.h,v $ V%Q% $Revision: 1.27 $ $Date: 1997/03/24 10:24:41 $
 */

#define DR1
#define DR2

#ifdef SPRLIB
#include <stdio.h>
#endif
#ifdef lint
#include <stdio.h>
#endif

/*
 * General library constants, error status return codes.
 */

#ifndef TRUE
#define TRUE 			(-1)
#endif

#ifndef FALSE
#define FALSE 	 	(0)
#endif

/*
 * Allow void pointers to be any type of pointer.
 */

#define VOID			void

/*
 * Union for special data used by algorithms.
 */
 
typedef union system_data
{
   double d;
   long l;
   VOID *p;
} SYSDATA;

/*
 * Some handy pre-processor commands.
 */

#ifndef MAX
#define MAX(a,b)  (a > b ? a : b)
#endif

#ifndef MIN
#define MIN(a,b)  (a < b ? a : b)
#endif

#ifndef ABS
#define ABS(a)    (a > 0 ? a : -a)
#endif

#include <nrutil.h>
#include <pattern.h>

/* sys/bell.c */

#define S_BONG     0
#define S_CLICK    1
#define S_COWBELL  2
#define S_DOORBELL 3
#define S_WHISTLE  4
#define S_SPLAT    5
#define S_ROOSTER  6

#ifdef SUN4
void 			sound_sample 				(int id);
#else
void			sound_sample				(void);
#endif

/* sys/fileio.c */
void 			init_full_fname 		(void);
char 		 *find_full_fname 		(char *FileName);

/* sys/monalloc.c */
char 		 *malloc_monitor 			(unsigned size, char *file, int line);
char 		 *calloc_monitor 			(unsigned nelm, unsigned elsize, char *file, int line);
void 			free_monitor 				(char *ptr, char *file_name, int line_number);
void 			status_monitor 			(int s);
unsigned 	memory_monitor 			(void);
#ifdef DR1
char 		 *realloc_monitor 		(char *ptr, unsigned size, char *file, int line);
#endif

#ifndef MONALLOC
#ifndef NO_MONITOR

#ifdef malloc
#undef malloc
#endif
#define malloc(size)       		malloc_monitor(((unsigned) size),__FILE__,__LINE__)

#ifdef calloc
#undef calloc
#endif
#define calloc(nelem,elsize) 	calloc_monitor(((unsigned) nelem),((unsigned) elsize),__FILE__,__LINE__)

#ifdef free
#undef free
#endif
#define free(ptr)            	free_monitor(((char *) ptr),__FILE__,__LINE__)

#ifdef DR1
#ifdef realloc
#undef realloc
#endif
#define realloc(ptr,size)    	realloc_monitor(((char *) ptr),((unsigned) size),__FILE__,__LINE__)
#endif

#endif
#endif 

/* sys/rusage.c */
int 			set_auto_priority 	(long seconds);
void 			clear_auto_priority (void);
int 			warning_system_load (double loadthres);

/* sys/sprutils.c */
#define INIT_STD    0x00
#define INIT_EXIT   0x01
#define INIT_SILENT 0x02
#define INIT_CORE   0x04
#define INIT_NOFPE  0x08
#define INIT_NOPRI  0x10 /* Undocumented feature. WSch. */
#ifdef DR2
#define INIT_HALT		0x20
#endif

#define EXIT_STD    0x00
#define EXIT_SILENT 0x01

void 			sprmessage 					(int type, char error_text[], char file_name[], int line_number);
float 		system_time 				(int function);
void 			sprinit 						(int c);
void 			sprexit 						(int s);

#define 	sprerror(str)   		sprmessage(0, (str),__FILE__,__LINE__)
#define 	sprwarning(str) 		sprmessage(1, (str),__FILE__,__LINE__)
#define 	sprdebug(str)   		sprmessage(2, (str),__FILE__,__LINE__)

/* sys/usignal.c */
int 			set_user_signal 		(void (*UserHandler)());
void 			clear_user_signal 	(void);

#include <statlib.h>
#include <netlib.h>
#include <version.h>

#undef DR1
#undef DR2

/*
 * End of include file.
 */

